package com.sooka.system.mapper;

import java.util.List;
import com.sooka.system.domain.TUParamspublic;

/**
 * 公共请求参数Mapper接口
 * 
 * @author lei
 * @date 2021-07-01
 */
public interface TUParamspublicMapper 
{
    /**
     * 查询公共请求参数
     * 
     * @param id 公共请求参数ID
     * @return 公共请求参数
     */
    public TUParamspublic selectTUParamspublicById(String id);

    /**
     * 查询公共请求参数列表
     * 
     * @param tUParamspublic 公共请求参数
     * @return 公共请求参数集合
     */
    public List<TUParamspublic> selectTUParamspublicList(TUParamspublic tUParamspublic);

    /**
     * 新增公共请求参数
     * 
     * @param tUParamspublic 公共请求参数
     * @return 结果
     */
    public int insertTUParamspublic(TUParamspublic tUParamspublic);

    /**
     * 修改公共请求参数
     * 
     * @param tUParamspublic 公共请求参数
     * @return 结果
     */
    public int updateTUParamspublic(TUParamspublic tUParamspublic);

    /**
     * 删除公共请求参数
     * 
     * @param id 公共请求参数ID
     * @return 结果
     */
    public int deleteTUParamspublicById(String id);

    /**
     * 批量删除公共请求参数
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTUParamspublicByIds(String[] ids);
}
